@@ -607,5 +607,5 @@ static void tray_icon_on_popup_menu(GtkStatusIcon *status_icon, guint button,
 
     self = user_data;
 
-    gtk_menu_popup(self->menu, NULL, NULL, NULL, NULL, button, activate_time);
+    gtk_menu_popup_at_pointer(self->menu, NULL);
 }
